==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Transports/mms/translations/mms_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="33"/>
        <source>MMS Plugin</source>
        <translation>Suplemento MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>About MMS Transport Plugin</source>
        <translation>Sobre o suplemento MMS Transport</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Suplemento Qmmp MMS Transport</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Memória:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Transports/mms/translations/mms_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="32"/>
        <source>MMS Plugin</source>
        <translation>Suplemento MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="52"/>
        <source>About MMS Transport Plugin</source>
        <translation>Acerca de suplemento MMS Transport</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Suplemento Qmmp MMS Transport</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Memória:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
